@@ -1,13 +1,13 @@
 /*
  * gedit-charmap-plugin.c - Character map side-pane for gedit
- * 
+ *
  * Copyright (C) 2006 Steve Frécinaux
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -32,12 +32,7 @@
 #include <gedit/gedit-document.h>
 #include <gedit/gedit-prefs-manager.h>
 
-#ifdef HAVE_GUCHARMAP_2
 #include <gucharmap/gucharmap.h>
-#else
-#include <gucharmap/gucharmap-table.h>
-#include <gucharmap/gucharmap-unicode-info.h>
-#endif
 
 #define WINDOW_DATA_KEY	"GeditCharmapPluginWindowData"
 
@@ -77,11 +72,7 @@ free_window_data (WindowData *data)
 }
 
 static void
-#ifdef HAVE_GUCHARMAP_2
 on_table_status_message (GucharmapChartable *chartable,
-#else
-on_table_status_message (GucharmapTable *chartable,
-#endif
 			 const gchar    *message,
 			 GeditWindow    *window)
 {
@@ -100,27 +91,19 @@ on_table_status_message (GucharmapTable *chartable,
 }
 
 static void
-#ifdef HAVE_GUCHARMAP_2
 on_table_sync_active_char (GucharmapChartable *chartable,
 			   GParamSpec         *psepc,
 			   GeditWindow        *window)
-#else
-on_table_set_active_char (GucharmapTable *chartable,
-			  gunichar        wc,
-			  GeditWindow    *window)
-#endif
 {
 	GString *gs;
 	const gchar **temps;
 	gint i;
-#ifdef HAVE_GUCHARMAP_2
-        gunichar wc;
+	gunichar wc;
 
-        wc = gucharmap_chartable_get_active_character (chartable);
-#endif
+	wc = gucharmap_chartable_get_active_character (chartable);
 
 	gs = g_string_new (NULL);
-	g_string_append_printf (gs, "U+%4.4X %s", wc, 
+	g_string_append_printf (gs, "U+%4.4X %s", wc,
 				gucharmap_get_unicode_name (wc));
 
 	temps = gucharmap_get_nameslist_equals (wc);
@@ -150,72 +133,54 @@ on_table_focus_out_event (GtkWidget      *drawing_area,
 			  GdkEventFocus  *event,
 			  GeditWindow    *window)
 {
-#ifdef HAVE_GUCHARMAP_2
 	GucharmapChartable *chartable;
-#else
-	GucharmapTable *chartable;
-#endif
 	WindowData *data;
-	
+
 	data = (WindowData *) g_object_get_data (G_OBJECT (window),
 						 WINDOW_DATA_KEY);
 	g_return_val_if_fail (data != NULL, FALSE);
 
-#ifdef HAVE_GUCHARMAP_2
 	chartable = gedit_charmap_panel_get_chartable
 					(GEDIT_CHARMAP_PANEL (data->panel));
-#else
-	chartable = gedit_charmap_panel_get_table
-					(GEDIT_CHARMAP_PANEL (data->panel));
-#endif
 
 	on_table_status_message (chartable, NULL, window);
 	return FALSE;
 }
 
-#ifdef HAVE_GUCHARMAP_2
 static void
 on_table_activate (GucharmapChartable *chartable,
 		   GeditWindow *window)
-#else
-static void
-on_table_activate (GucharmapTable *chartable, 
-		   gunichar        wc, 
-		   GeditWindow    *window)
-#endif
 {
 	GtkTextView   *view;
 	GtkTextBuffer *document;
 	GtkTextIter start, end;
 	gchar buffer[6];
 	gchar length;
-#ifdef HAVE_GUCHARMAP_2
         gunichar wc;
 
         wc = gucharmap_chartable_get_active_character (chartable);
-#endif
-	
+
 	g_return_if_fail (gucharmap_unichar_validate (wc));
-	
+
 	view = GTK_TEXT_VIEW (gedit_window_get_active_view (window));
-	
+
 	if (!view || !gtk_text_view_get_editable (view))
 		return;
-	
+
 	document = gtk_text_view_get_buffer (view);
-	
+
 	g_return_if_fail (document != NULL);
-	
+
 	length = g_unichar_to_utf8 (wc, buffer);
 
 	gtk_text_buffer_begin_user_action (document);
-		
+
 	gtk_text_buffer_get_selection_bounds (document, &start, &end);
 
 	gtk_text_buffer_delete_interactive (document, &start, &end, TRUE);
 	if (gtk_text_iter_editable (&start, TRUE))
 		gtk_text_buffer_insert (document, &start, buffer, length);
-	
+
 	gtk_text_buffer_end_user_action (document);
 }
 
@@ -223,30 +188,22 @@ static GtkWidget *
 create_charmap_panel (GeditWindow *window)
 {
 	GtkWidget      *panel;
-#ifdef HAVE_GUCHARMAP_2
-        GucharmapChartable *chartable;
-#else
-	GucharmapTable *table;
-#endif
-	gchar          *font;
+	GucharmapChartable *chartable;
+	PangoFontDescription *font_desc;
+	gchar *font;
 
 	panel = gedit_charmap_panel_new ();
 
 	/* Use the same font as the document */
 	font = gedit_prefs_manager_get_editor_font ();
 
-#ifdef HAVE_GUCHARMAP_2
 	chartable = gedit_charmap_panel_get_chartable (GEDIT_CHARMAP_PANEL (panel));
-	gucharmap_chartable_set_font_desc (chartable, 
-					   pango_font_description_from_string (font));
-#else
-	table = gedit_charmap_panel_get_table (GEDIT_CHARMAP_PANEL (panel));
-	gucharmap_table_set_font (table, font);
-#endif
+	font_desc = pango_font_description_from_string (font);
+	gucharmap_chartable_set_font_desc (chartable, font_desc);
+	pango_font_description_free (font_desc);
 
 	g_free (font);
 
-#ifdef HAVE_GUCHARMAP_2
 	g_signal_connect (chartable,
 			  "notify::active-character",
 			  G_CALLBACK (on_table_sync_active_char),
@@ -260,30 +217,10 @@ create_charmap_panel (GeditWindow *window)
 			  G_CALLBACK (on_table_status_message),
 			  window);
 	g_signal_connect (chartable,
-			  "activate", 
+			  "activate",
 			  G_CALLBACK (on_table_activate),
 			  window);
 
-#else
-	g_signal_connect (table,
-			  "set-active-char",
-			  G_CALLBACK (on_table_set_active_char),
-			  window);
-	/* Note: GucharmapTable does not provide focus-out-event ... */
-	g_signal_connect (table->drawing_area,
-			  "focus-out-event",
-			  G_CALLBACK (on_table_focus_out_event),
-			  window);
-	g_signal_connect (table,
-			  "status-message",
-			  G_CALLBACK (on_table_status_message),
-			  window);
-	g_signal_connect (table,
-			  "activate", 
-			  G_CALLBACK (on_table_activate),
-			  window);
-#endif /* HAVE_GUCHARMAP_2 */
-
 	gtk_widget_show_all (panel);
 
 	return panel;
@@ -306,7 +243,7 @@ impl_activate (GeditPlugin *plugin,
 	data = g_slice_new (WindowData);
 
 	theme = gtk_icon_theme_get_default ();
-	
+
 	if (gtk_icon_theme_has_icon (theme, "accessories-character-map"))
 		image = gtk_image_new_from_icon_name ("accessories-character-map",
 						      GTK_ICON_SIZE_MENU);
@@ -315,9 +252,10 @@ impl_activate (GeditPlugin *plugin,
 						      GTK_ICON_SIZE_MENU);
 
 	data->panel = create_charmap_panel (window);
-	
+
 	gedit_panel_add_item (panel,
 			      data->panel,
+			      "GeditCharmapPanel",
 			      _("Character Map"),
 			      image);
 
@@ -339,11 +277,7 @@ impl_deactivate	(GeditPlugin *plugin,
 {
 	GeditPanel *panel;
 	WindowData *data;
-#ifdef HAVE_GUCHARMAP_2
 	GucharmapChartable *chartable;
-#else
-	GucharmapTable *chartable;
-#endif
 
 	gedit_debug (DEBUG_PLUGINS);
 
@@ -351,13 +285,8 @@ impl_deactivate	(GeditPlugin *plugin,
 						 WINDOW_DATA_KEY);
 	g_return_if_fail (data != NULL);
 
-#ifdef HAVE_GUCHARMAP_2
 	chartable = gedit_charmap_panel_get_chartable
 					(GEDIT_CHARMAP_PANEL (data->panel));
-#else
-	chartable = gedit_charmap_panel_get_table
-					(GEDIT_CHARMAP_PANEL (data->panel));
-#endif
 	on_table_status_message (chartable, NULL, window);
 
 	panel = gedit_window_get_side_panel (window);
